public class GrayscaleFilter implements PixelFilter, ParameterizedFilter {
	private final IntFilterParam thresholdMinParam =
		new IntFilterParam("Threshold - Minimum", 0, 255, 0);
	private final IntFilterParam thresholdMaxParam =
		new IntFilterParam("Threshold - Maximum", 0, 255, 255);
	
	private final FilterParam[] params = new FilterParam[] {
		thresholdMinParam,
		thresholdMaxParam
	};
	
	// ### FILTER ###
	
	public int filter(int pixel) {
		int grayPixel = Pixels.ARGBToGray(pixel);
		if (grayPixel < thresholdMinParam.getValue())
			return Pixels.BLACK_ARGB_PIXEL;
		if (grayPixel > thresholdMaxParam.getValue())
			return Pixels.WHITE_ARGB_PIXEL;
		return Pixels.grayToARGB(grayPixel);
	}
	
	public String toString() {
		return "Grayscale";
	}
	
	// ### PARAMETERIZED FILTER ###
	
	public FilterParam[] getParams() {
		return params;
	}
}