// NOTE: this filter is never directional (when distinguishing types of contours)

public class StarContourExtractionFilter extends AveragingFilter implements ParameterizedFilter {
	private final IntFilterParam stippleRadiusParam
		= new IntFilterParam("Stipple Radius", 1, Integer.MAX_VALUE, 5);
	
	private final FilterParam[] params = new FilterParam[] {
		stippleRadiusParam
	};
	
	// ### INIT ###
	
	public StarContourExtractionFilter() {
		this(5);
	}
	
	/**
	 * @param stippleRadius		specifies the radius of the smallest blob 
	 * 							whose contours the filter can find effectively;
	 * 							(use smaller values to detect the contours of thinner objects)
	 */
	public StarContourExtractionFilter(int stippleRadius) {
		super(new PixelBufferFilter2[] {
			new HorizontalContourExtractionFilter(stippleRadius, false),
			new VerticalContourExtractionFilter(stippleRadius, false),
			new DiagonalContourExtractionFilter(stippleRadius, false),
			new AntidiagonalContourExtractionFilter(stippleRadius, false)
		});
	}
	
	// ### FILTER ###
	
	public void filter(int width, int height, int[] inPixels, int[] outPixels) {
		// Update parameters of base-filters
		// XXX: method of update is dependent on the order that
		//      HorizontalContourExtractionFilter and VerticalContourExtractionFilter
		//      specify their parameters in
		((IntFilterParam) ((HorizontalContourExtractionFilter) super.filters[0]).getParams()[0]).
			setValue(stippleRadiusParam.getValue());
		((IntFilterParam) ((VerticalContourExtractionFilter) super.filters[1]).getParams()[0]).
			setValue(stippleRadiusParam.getValue());
		((IntFilterParam) ((DiagonalContourExtractionFilter) super.filters[2]).getParams()[0]).
			setValue(stippleRadiusParam.getValue());
		((IntFilterParam) ((AntidiagonalContourExtractionFilter) super.filters[3]).getParams()[0]).
			setValue(stippleRadiusParam.getValue());
		
		// Delegate filtering to superclass
		super.filter(width, height, inPixels, outPixels);
	}
	
	public String toString() {
		return "Contour Extraction (Star)";
	}
	
	// ### PARAMETERIZED FILTER ###
	
	public FilterParam[] getParams() {
		return params;
	}
}